
## Release Notes

**v0.3.0 - May 29, 2023**

- **FEATURE**: localisation distances are returned for each sky-position (if requested)
- **ENHANCEMENT**: probability clearly reported as a % on the command-line
- **ENHANCEMENT**: support for bilby generated maps

**v0.2.0 - April 28, 2023**

- First release
